# update.py
from akerbp.mlops.core import logger
from akerbp.mlops.deployment.setup import setup_pipeline
from  akerbp.mlops.core.config import validate_user_settings

logging=logger.get_logger(name='mlops_core')

logging.info("Create or overwrite pipeline file")
setup_pipeline(overwrite=True) 
logging.info("Validate settings file")
validate_user_settings()
logging.info("Done!")



# helpers.py
import os
from pathlib import Path

from akerbp.mlops.core import logger


logging=logger.get_logger(name='mlops_core')

def get_top_folder(s):
    if isinstance(s, str):
        return s.split(os.sep)[0]
    elif isinstance(s, Path):
        return s.parents[len(s.parents)-2]


def as_import_path(file_path):
    if file_path:
        if not isinstance(file_path, str):
            file_path=str(file_path)
        return file_path.replace(os.sep,'.').replace('.py','')
    else:
        logging.debug(f"Empty file path -> empty import path returned")
